==> jc-1.4.0.tar.gz: java/awt/event/WindowEvent.h <==
// public class java.awt.event.WindowEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class a19ffadc4d88c183 java_awt_event_WindowEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_WindowEvent_H_
#define _JC_java_awt_event_WindowEvent_H_

// Forward structure declarations
struct _jc_java_awt_Window$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_WindowEvent$sub_refs	_jc_java_awt_event_WindowEvent$sub_refs;
typedef struct _jc_java_awt_event_WindowEvent$sub_nonrefs	_jc_java_awt_event_WindowEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_WindowEvent$refs	_jc_java_awt_event_WindowEvent$refs;
typedef struct _jc_java_awt_event_WindowEvent$nonrefs	_jc_java_awt_event_WindowEvent$nonrefs;
typedef struct _jc_java_awt_event_WindowEvent$object	_jc_java_awt_event_WindowEvent$object;

typedef struct _jc_java_awt_event_WindowEvent$fields_struct	_jc_java_awt_event_WindowEvent$fields_struct;
typedef const struct _jc_java_awt_event_WindowEvent$vmethods	_jc_java_awt_event_WindowEvent$vmethods;
typedef const struct _jc_java_awt_event_WindowEvent$vtable	_jc_java_awt_event_WindowEvent$vtable;
typedef const struct _jc_java_awt_event_WindowEvent$vtype	_jc_java_awt_event_WindowEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_WindowEvent$fields_struct {
	jlong	serialVersionUID;
	jint	WINDOW__5fACTIVATED;
	jint	WINDOW__5fCLOSED;
	jint	WINDOW__5fCLOSING;
	jint	WINDOW__5fDEACTIVATED;
	jint	WINDOW__5fDEICONIFIED;
	jint	WINDOW__5fFIRST;
	jint	WINDOW__5fGAINED__5fFOCUS;
	jint	WINDOW__5fICONIFIED;
	jint	WINDOW__5fLAST;
	jint	WINDOW__5fLOST__5fFOCUS;
	jint	WINDOW__5fOPENED;
	jint	WINDOW__5fSTATE__5fCHANGED;
};
extern _jc_java_awt_event_WindowEvent$fields_struct _jc_java_awt_event_WindowEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_WindowEvent$method$_init$ea09f3e1e65e0563(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *, struct _jc_java_awt_Window$object *, jint);
extern void _jc_java_awt_event_WindowEvent$method$_init$dbae8984e194f4dd(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *, struct _jc_java_awt_Window$object *, jint, jint, jint);
extern void _jc_java_awt_event_WindowEvent$method$_init$48a4a2296369dd1a(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *, struct _jc_java_awt_Window$object *, jint, struct _jc_java_awt_Window$object *);
extern void _jc_java_awt_event_WindowEvent$method$_init$e092c9664539c913(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *, struct _jc_java_awt_Window$object *, jint, struct _jc_java_awt_Window$object *, jint, jint);

// Virtual methods
extern jint _jc_java_awt_event_WindowEvent$method$getNewState$0ef214bb1771aee9(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);
extern jint _jc_java_awt_event_WindowEvent$method$getOldState$55b2c6b00cbd8678(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);
extern struct _jc_java_awt_Window$object *_jc_java_awt_event_WindowEvent$method$getOppositeWindow$7a8c85f474f1d8f0(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);
extern struct _jc_java_awt_Window$object *_jc_java_awt_event_WindowEvent$method$getWindow$507bd07125509112(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_WindowEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$getNewState$0ef214bb1771aee9;
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$getOldState$55b2c6b00cbd8678;
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$getOppositeWindow$7a8c85f474f1d8f0;
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$getWindow$507bd07125509112;
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_WindowEvent$vmethods {
	jint	(*getNewState$0ef214bb1771aee9)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);
	jint	(*getOldState$55b2c6b00cbd8678)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);
	struct _jc_java_awt_Window$object	*(*getOppositeWindow$7a8c85f474f1d8f0)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);
	struct _jc_java_awt_Window$object	*(*getWindow$507bd07125509112)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *);
};

// Vtable
struct _jc_java_awt_event_WindowEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_WindowEvent$vmethods	java_awt_event_WindowEvent;
};

// Vtype
struct _jc_java_awt_event_WindowEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_WindowEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_WindowEvent$sub_refs {
	struct _jc_java_awt_Window$object	*opposite;
};

// Reference instance fields (object)
struct _jc_java_awt_event_WindowEvent$refs {
    _jc_java_awt_event_WindowEvent$sub_refs	java_awt_event_WindowEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_WindowEvent$sub_nonrefs {
	jint	oldState;
	jint	newState;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_WindowEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_WindowEvent$sub_nonrefs	java_awt_event_WindowEvent;
};

// Object instance structure
struct _jc_java_awt_event_WindowEvent$object {
	_jc_java_awt_event_WindowEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_WindowEvent$vtype	*vtype;
	_jc_java_awt_event_WindowEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_WindowEvent$vtype _jc_java_awt_event_WindowEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_WindowEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_WindowEvent$class_object;

#endif	/* _JC_java_awt_event_WindowEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/WindowEvent.h <==
// public class java.awt.event.WindowEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class a19ffadc4d88c183 java_awt_event_WindowEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_WindowEvent_H_
#define _JC_java_awt_event_WindowEvent_H_

// Forward structure declarations
struct _jc_java_awt_Window$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_WindowEvent$sub_refs	_jc_java_awt_event_WindowEvent$sub_refs;
typedef struct _jc_java_awt_event_WindowEvent$sub_nonrefs	_jc_java_awt_event_WindowEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_WindowEvent$refs	_jc_java_awt_event_WindowEvent$refs;
typedef struct _jc_java_awt_event_WindowEvent$nonrefs	_jc_java_awt_event_WindowEvent$nonrefs;
typedef struct _jc_java_awt_event_WindowEvent$object	_jc_java_awt_event_WindowEvent$object;

typedef struct _jc_java_awt_event_WindowEvent$fields_struct	_jc_java_awt_event_WindowEvent$fields_struct;
typedef const struct _jc_java_awt_event_WindowEvent$vmethods	_jc_java_awt_event_WindowEvent$vmethods;
typedef const struct _jc_java_awt_event_WindowEvent$vtable	_jc_java_awt_event_WindowEvent$vtable;
typedef const struct _jc_java_awt_event_WindowEvent$vtype	_jc_java_awt_event_WindowEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_WindowEvent$fields_struct {
	jlong	serialVersionUID;
	jint	WINDOW__5fACTIVATED;
	jint	WINDOW__5fCLOSED;
	jint	WINDOW__5fCLOSING;
	jint	WINDOW__5fDEACTIVATED;
	jint	WINDOW__5fDEICONIFIED;
	jint	WINDOW__5fFIRST;
	jint	WINDOW__5fGAINED__5fFOCUS;
	jint	WINDOW__5fICONIFIED;
	jint	WINDOW__5fLAST;
	jint	WINDOW__5fLOST__5fFOCUS;
	jint	WINDOW__5fOPENED;
	jint	WINDOW__5fSTATE__5fCHANGED;
};
extern _jc_java_awt_event_WindowEvent$fields_struct _jc_java_awt_event_WindowEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_WindowEvent$method$_init$ea09f3e1e65e0563(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *, struct _jc_java_awt_Window$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_WindowEvent$method$_init$dbae8984e194f4dd(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *, struct _jc_java_awt_Window$object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_WindowEvent$method$_init$48a4a2296369dd1a(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *, struct _jc_java_awt_Window$object *, jint, struct _jc_java_awt_Window$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_WindowEvent$method$_init$e092c9664539c913(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *, struct _jc_java_awt_Window$object *, jint, struct _jc_java_awt_Window$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_event_WindowEvent$method$getNewState$0ef214bb1771aee9(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_WindowEvent$method$getOldState$55b2c6b00cbd8678(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Window$object *_jc_java_awt_event_WindowEvent$method$getOppositeWindow$7a8c85f474f1d8f0(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Window$object *_jc_java_awt_event_WindowEvent$method$getWindow$507bd07125509112(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_WindowEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$getNewState$0ef214bb1771aee9;
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$getOldState$55b2c6b00cbd8678;
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$getOppositeWindow$7a8c85f474f1d8f0;
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$getWindow$507bd07125509112;
extern _jc_method _jc_java_awt_event_WindowEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_WindowEvent$vmethods {
	jint	(*getNewState$0ef214bb1771aee9)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
	jint	(*getOldState$55b2c6b00cbd8678)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Window$object	*(*getOppositeWindow$7a8c85f474f1d8f0)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Window$object	*(*getWindow$507bd07125509112)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_WindowEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_WindowEvent$vmethods	java_awt_event_WindowEvent;
};

// Vtype
struct _jc_java_awt_event_WindowEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_WindowEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_WindowEvent$sub_refs {
	struct _jc_java_awt_Window$object	*opposite;
};

// Reference instance fields (object)
struct _jc_java_awt_event_WindowEvent$refs {
    _jc_java_awt_event_WindowEvent$sub_refs	java_awt_event_WindowEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_WindowEvent$sub_nonrefs {
	jint	oldState;
	jint	newState;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_WindowEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_WindowEvent$sub_nonrefs	java_awt_event_WindowEvent;
};

// Object instance structure
struct _jc_java_awt_event_WindowEvent$object {
	_jc_java_awt_event_WindowEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_WindowEvent$vtype	*vtype;
	_jc_java_awt_event_WindowEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_WindowEvent$vtype _jc_java_awt_event_WindowEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_WindowEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_WindowEvent$class_object;

#endif	/* _JC_java_awt_event_WindowEvent_H_ */
